@@ -2,12 +2,12 @@ from os.path import dirname, abspath
 import sys
 from importlib import import_module
 
+from hestia_earth.models.utils.blank_node import run_if_required
+
 CURRENT_DIR = dirname(abspath(__file__)) + '/'
 sys.path.append(CURRENT_DIR)
 MODEL = 'agribalyse2016'
 PKG = '.'.join(['hestia_earth', 'models', MODEL])
 
 
-def run(model: str, data):
-    run = getattr(import_module(f".{model}", package=PKG), 'run')
-    return run(data)
+def run(model: str, data): return run_if_required(MODEL, model, data, import_module(f".{model}", package=PKG))
