@@ -20,8 +20,12 @@ def get_ecoClimateZone_lookup_value(eco_climate_zone: str, col_name: str, group_
     float
         The value associated with the `ecoClimateZone`.
     """
-    lookup = download_lookup('ecoClimateZone.csv', True)
-    data = _get_single_table_value(lookup, column_name('ecoClimateZone'), int(eco_climate_zone), column_name(col_name))
-    return safe_parse_float(
-        data if group_name is None else extract_grouped_data(data, group_name)
-    )
+    try:
+        lookup = download_lookup('ecoClimateZone.csv')
+        code = int(str(eco_climate_zone))
+        data = _get_single_table_value(lookup, column_name('ecoClimateZone'), code, column_name(col_name))
+        return safe_parse_float(
+            data if group_name is None else extract_grouped_data(data, group_name)
+        )
+    except Exception:
+        return 0
