@@ -1,39 +1,37 @@
 from unittest.mock import patch
 import json
+from hestia_earth.schema import TermTermType
+
 from tests.utils import fixtures_path, fake_new_emission
+from hestia_earth.models.ipcc2006.n2OToAirExcretaIndirect import MODEL, TERM_ID, run, _should_run
 
-from hestia_earth.models.ipcc2006.n2OToAirExcretaIndirect import TERM_ID, run, _should_run
-
-class_path = f"hestia_earth.models.ipcc2006.{TERM_ID}"
-fixtures_folder = f"{fixtures_path}/ipcc2006/{TERM_ID}"
+class_path = f"hestia_earth.models.{MODEL}.{TERM_ID}"
+fixtures_folder = f"{fixtures_path}/{MODEL}/{TERM_ID}"
 
 
-def test_should_run():
+@patch(f"{class_path}._is_term_type_complete", return_value=False)
+def test_should_run(mock_is_complete, *args):
     # no products => no run
     cycle = {'products': []}
     should_run, *args = _should_run(cycle)
     assert not should_run
 
-    # with kg N products => no run
+    # with kg N products => run
     cycle['products'] = [{
         'term': {
             'units': 'kg N',
-            'termType': 'animalProduct'
+            'termType': TermTermType.EXCRETA.value
         },
         'value': [100]
     }]
     should_run, *args = _should_run(cycle)
-    assert not should_run
+    assert should_run is True
 
-    # with no3 emission => run
-    cycle['emissions'] = [{
-        'term': {
-            '@id': 'no3ToGroundwaterExcreta'
-        },
-        'value': [100]
-    }]
+    # is complete => run
+    cycle['products'] = []
+    mock_is_complete.return_value = True
     should_run, *args = _should_run(cycle)
-    assert should_run
+    assert should_run is True
 
 
 @patch(f"{class_path}._new_emission", side_effect=fake_new_emission)
